PromptMask WebUI

Original Text
Masked Text Mask Map

    {...}

Unmasked Text
Original Messages
Masked Messages (JSON) Mask Map

    {...}

Unmasked Messages (JSON)

### Gateway Status

Health Check: UNKNOWN

### Gateway Live Test (Chat Completion Stream)

Upstream Target: `loading...`
This is controlled by `web.upstream_oai_api_base` in your configuration (Settings tab).

Request Headers
Request Body Parameters
Messages
Live Original (Masked) Stream Output

Live Unmasked Stream Output

### Configuration

View and edit `promptmask.config.user.toml`. Changes are hot-reloaded on the server.

Config (JSON format for editing)

Status: